@@ -18,7 +18,7 @@ from .mscope import Scope
 from .ast_function_definition import FunctionDefinition
 from .value_item import ValueItem
 from .__about__ import __author__, __author_email__, __credits__, __version__
-from .interpreter import validateFunctionArguments
+from .interpreter import ValidateFunctionArguments
 
 
 __all__ = [
@@ -45,5 +45,5 @@ __all__ = [
     '__author_email__',
     '__credits__',
     '__version__',
-    'validateFunctionArguments'
+    'ValidateFunctionArguments'
 ]
\ No newline at end of file
